src package
===========

Submodules
----------

src.settings module
-------------------

.. automodule:: src.cli
   :members:
   :undoc-members:
   :show-inheritance:

src.template module
-------------------

.. automodule:: src.pizazz
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: src
   :members:
   :undoc-members:
   :show-inheritance:
